@@ -11,9 +11,10 @@ use Plack::Util::Accessor qw/
     id_generator
     force_generate_id
     env_key
+    no_http_header
 /;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 our $request_id;
 
@@ -59,7 +60,7 @@ sub call {
 
     $self->response_cb($res, sub {
         my $res = shift;
-        if ($res) {
+        if ($res && !$self->no_http_header) {
             Plack::Util::header_push(
                 $res->[1],
                 $self->http_header,
@@ -113,6 +114,10 @@ The key string for storing an ID in PSGI environment variables. default: C<psgix
 
 The key string for an ID in HTTP Headers. default: C<X-Request-Id>
 
+=head2 no_http_header
+
+If this option was set true value then the request id does not put in HTTP Headers.
+
 =head2 id_generator
 
 The code ref for generating an ID. By default, using L<Data::UUID>.
@@ -146,7 +151,7 @@ Normally, you get the request ID from PSGI env. However, the ID has been stored
 
 =begin html
 
-<a href="http://travis-ci.org/bayashi/Plack-Middleware-RequestId"><img src="https://secure.travis-ci.org/bayashi/Plack-Middleware-RequestId.png?_t=1464415439"/></a> <a href="https://coveralls.io/r/bayashi/Plack-Middleware-RequestId"><img src="https://coveralls.io/repos/bayashi/Plack-Middleware-RequestId/badge.png?_t=1464415439&branch=master"/></a>
+<a href="http://travis-ci.org/bayashi/Plack-Middleware-RequestId"><img src="https://secure.travis-ci.org/bayashi/Plack-Middleware-RequestId.png?_t=1467254265"/></a> <a href="https://coveralls.io/r/bayashi/Plack-Middleware-RequestId"><img src="https://coveralls.io/repos/bayashi/Plack-Middleware-RequestId/badge.png?_t=1467254265&branch=master"/></a>
 
 =end html
 
